struct ServoShellServoDelegate;Trait Implementations
Sourceimpl ServoDelegate for ServoShellServoDelegate
impl ServoDelegate for ServoShellServoDelegate
Sourcefn notify_devtools_server_started(&self, port: u16, _token: String)
fn notify_devtools_server_started(&self, port: u16, _token: String)
Report that the DevTools server has started on the given
port. The token that
be used to bypass the permission prompt from the DevTools client.Sourcefn request_devtools_connection(&self, request: AllowOrDenyRequest)
fn request_devtools_connection(&self, request: AllowOrDenyRequest)
Request a DevTools connection from a DevTools client. Typically an embedder application
will show a permissions prompt when this happens to confirm a connection is allowed.
Sourcefn notify_error(&self, error: ServoError)
fn notify_error(&self, error: ServoError)
Notification that Servo has received a major error.
Sourcefn show_console_message(&self, level: ConsoleLogLevel, message: String)
fn show_console_message(&self, level: ConsoleLogLevel, message: String)
Sourcefn load_web_resource(&self, _load: WebResourceLoad)
fn load_web_resource(&self, _load: WebResourceLoad)
Triggered when Servo will load a web (HTTP/HTTPS) resource. The load may be
intercepted and alternate contents can be loaded by the client by calling
WebResourceLoad::intercept. If not handled, the load will continue as normal. Read moreSourcefn show_notification(&self, _notification: Notification)
fn show_notification(&self, _notification: Notification)
Request to display a notification.